@@ -9,7 +9,7 @@ use crate::event::{
 use crate::types::event::KitsuneP2pEventSender;
 use kitsune_p2p_types::{
     agent_info::AgentInfoSigned,
-    bin_types::{KitsuneAgent, KitsuneBinType, KitsuneOpHash, KitsuneSpace},
+    bin_types::{KitsuneAgent, KitsuneOpHash, KitsuneSpace},
     dht_arc::{ArcInterval, DhtArcSet},
     KitsuneError, KitsuneResult,
 };
@@ -133,31 +133,16 @@ pub(super) async fn all_op_hashes_within_arcset(
 pub(super) async fn put_agent_info(
     evt_sender: &EventSender,
     space: &Arc<KitsuneSpace>,
-    agents_within_common_arc: HashSet<Arc<KitsuneAgent>>,
     agents: &[Arc<AgentInfoSigned>],
 ) -> KitsuneResult<()> {
-    for this_agent_info in all_agent_info(evt_sender, space)
-        .await?
-        .into_iter()
-        .filter(|a| agents_within_common_arc.contains(a.agent.as_ref()))
-    {
-        let peer_data = agents
-            .iter()
-            .filter(|new_info| {
-                this_agent_info
-                    .storage_arc
-                    .contains(new_info.agent.get_loc())
-            })
-            .map(|i| (**i).clone())
-            .collect();
-        evt_sender
-            .put_agent_info_signed(PutAgentInfoSignedEvt {
-                space: space.clone(),
-                peer_data,
-            })
-            .await
-            .map_err(KitsuneError::other)?;
-    }
+    let peer_data = agents.iter().map(|i| (**i).clone()).collect();
+    evt_sender
+        .put_agent_info_signed(PutAgentInfoSignedEvt {
+            space: space.clone(),
+            peer_data,
+        })
+        .await
+        .map_err(KitsuneError::other)?;
     Ok(())
 }
 
@@ -184,17 +169,28 @@ pub(super) async fn put_ops(
     agent_arcs: Vec<(Arc<KitsuneAgent>, ArcInterval)>,
     ops: Vec<(Arc<KitsuneOpHash>, Vec<u8>)>,
 ) -> KitsuneResult<()> {
-    for (agent, arc) in agent_arcs {
-        let ops: Vec<_> = ops
-            .iter()
-            .filter(|(op_hash, _)| arc.contains(op_hash.get_loc()))
-            .cloned()
-            .collect();
-        if !ops.is_empty() {
-            evt_sender
-                .gossip(space.clone(), agent.clone(), ops)
-                .await
-                .map_err(KitsuneError::other)?;
+    // If there's only a single agent in the space we
+    // can avoid cloning the ops which could be large.
+    if agent_arcs.len() == 1 {
+        let (agent, arc) = agent_arcs
+            .into_iter()
+            .next()
+            .expect("Can't be none due to len check");
+        if arc.is_empty() {
+            return Ok(());
+        }
+        evt_sender
+            .gossip(space.clone(), agent, ops)
+            .await
+            .map_err(KitsuneError::other)?;
+    } else {
+        for (agent, arc) in agent_arcs {
+            if !arc.is_empty() {
+                evt_sender
+                    .gossip(space.clone(), agent, ops.clone())
+                    .await
+                    .map_err(KitsuneError::other)?;
+            }
         }
     }
 
