@@ -20,23 +20,21 @@ async fn standard_responses(
 ) -> MockKitsuneP2pEventHandler {
     let mut evt_handler = MockKitsuneP2pEventHandler::new();
     let agents: Vec<_> = agents_with_arcs.iter().map(|(a, _)| a.clone()).collect();
-    evt_handler
-        .expect_handle_query_agent_info_signed()
-        .returning({
+    evt_handler.expect_handle_query_agents().returning({
+        let agents = agents.clone();
+        move |_| {
             let agents = agents.clone();
-            move |_| {
-                let agents = agents.clone();
-                Ok(async move {
-                    let mut infos = Vec::new();
-                    for agent in agents {
-                        infos.push(agent_info(agent).await);
-                    }
-                    Ok(infos)
+            Ok(async move {
+                let mut infos = Vec::new();
+                for agent in agents {
+                    infos.push(agent_info(agent).await);
                 }
-                .boxed()
-                .into())
+                Ok(infos)
             }
-        });
+            .boxed()
+            .into())
+        }
+    });
     evt_handler
         .expect_handle_get_agent_info_signed()
         .returning({
@@ -49,18 +47,13 @@ async fn standard_responses(
                     .into())
             }
         });
-    evt_handler.expect_handle_query_gossip_agents().returning({
-        move |_| {
-            let agents_with_arcs = agents_with_arcs.clone();
-            Ok(async move { Ok(agents_with_arcs) }.boxed().into())
-        }
-    });
+
     if with_data {
         evt_handler.expect_handle_query_op_hashes().returning(|_| {
             Ok(async {
                 Ok(Some((
                     vec![Arc::new(KitsuneOpHash(vec![0; 36]))],
-                    full_time_range(),
+                    full_time_window(),
                 )))
             }
             .boxed()
@@ -122,17 +115,27 @@ pub fn agents_with_full_arcs(num_agents: usize) -> Vec<(Arc<KitsuneAgent>, ArcIn
 }
 
 pub async fn agent_info(agent: Arc<KitsuneAgent>) -> AgentInfoSigned {
+    let rand_string: String = thread_rng()
+        .sample_iter(&rand::distributions::Alphanumeric)
+        .take(10)
+        .map(char::from)
+        .collect();
     AgentInfoSigned::sign(
-            Arc::new(fixt!(KitsuneSpace)),
-            agent,
-            u32::MAX / 4,
-            vec![url2::url2!("kitsune-proxy://CIW6PxKxsPPlcuvUCbMcKwUpaMSmB7kLD8xyyj4mqcw/kitsune-quic/h/localhost/p/5778/-").into()],
-            0,
-            0,
-            |_| async move { Ok(Arc::new(fixt!(KitsuneSignature, Predictable))) },
+        Arc::new(fixt!(KitsuneSpace)),
+        agent,
+        u32::MAX / 4,
+        vec![url2::url2!(
+            "kitsune-proxy://CIW6PxKxs{}cKwUpaMSmB7kLD8xyyj4mqcw/kitsune-quic/h/localhost/p/5778/-",
+            rand_string
         )
-        .await
-        .unwrap()
+        .into()],
+        std::time::UNIX_EPOCH.elapsed().unwrap().as_millis() as u64,
+        (std::time::UNIX_EPOCH.elapsed().unwrap() + std::time::Duration::from_secs(60 * 60))
+            .as_millis() as u64,
+        |_| async move { Ok(Arc::new(fixt!(KitsuneSignature, Predictable))) },
+    )
+    .await
+    .unwrap()
 }
 
 /// Create an AgentInfoSigned with arbitrary agent and arc.
@@ -158,6 +161,6 @@ pub fn dangerous_fake_agent_info_with_arc(
 
 pub fn empty_bloom() -> EncodedTimedBloomFilter {
     EncodedTimedBloomFilter::MissingAllHashes {
-        time_window: full_time_range(),
+        time_window: full_time_window(),
     }
 }
