@@ -284,7 +284,7 @@ impl SpaceInternalHandler for Space {
             let mut all = Vec::new();
             for info in info_list
                 .into_iter()
-                .filter(|info| info.agent.get_loc() % mod_cnt == mod_idx)
+                .filter(|info| info.agent.get_loc().as_u32() % mod_cnt == mod_idx)
             {
                 let ro_inner = ro_inner.clone();
                 let space = space.clone();
@@ -609,10 +609,21 @@ impl KitsuneP2pHandler for Space {
         &mut self,
         input: actor::RpcMulti,
     ) -> KitsuneP2pHandlerResult<Vec<actor::RpcMultiResponse>> {
+        let location = input.basis.get_loc();
+        let local_agents_holding_basis = self
+            .local_joined_agents
+            .iter()
+            .filter(|agent| {
+                self.agent_arcs
+                    .get(*agent)
+                    .map_or(false, |arc| arc.contains(location))
+            })
+            .cloned()
+            .collect();
         let fut = rpc_multi_logic::handle_rpc_multi(
             input,
             self.ro_inner.clone(),
-            self.local_joined_agents.clone(),
+            local_agents_holding_basis,
         );
         Ok(async move { fut.await }.boxed().into())
     }
